==> phpnuke-5.5.tgz: www/phpnuke/html/modules/Recommend_Us/language/lang-dutch.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please sent to me (fbc@mandrakesoft.com)    */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_SEND","Verzenden");
define("_FYOURNAME","Uw naam:");
define("_FYOUREMAIL","Uw e-mail:");
define("_FFRIENDNAME","De naam van uw kennis:");
define("_FFRIENDEMAIL","Het e-mailadres van uw kennis:");
define("_HELLO","Hallo");
define("_YOURFRIEND","Uw kennis");
define("_RECOMMEND","Deze ste aanbevelen aan een kennis");
define("_INTSITE","Interessante site:");
define("_OURSITE","vond onze site");
define("_INTSENT","interessant en wilde deze naar u verzenden.");
define("_FSITENAME","Sitenaam:");
define("_FSITEURL","Site URL:");
define("_FREFERENCE","De referentie naar onze site is verzonden naar");
define("_THANKSREC","Bedankt voor uw aanbeveling!");

?>

==> phpnuke-5.6.tgz: www/phpnuke/html/modules/Recommend_Us/language/lang-dutch.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please go to the site and send to me        */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_SEND","Verzenden");
define("_FYOURNAME","Uw naam:");
define("_FYOUREMAIL","Uw e-mail:");
define("_FFRIENDNAME","De naam van uw kennis:");
define("_FFRIENDEMAIL","Het e-mailadres van uw kennis:");
define("_HELLO","Hallo");
define("_YOURFRIEND","Uw kennis");
define("_RECOMMEND","Deze ste aanbevelen aan een kennis");
define("_INTSITE","Interessante site:");
define("_OURSITE","vond onze site");
define("_INTSENT","interessant en wilde deze naar u verzenden.");
define("_FSITENAME","Sitenaam:");
define("_FSITEURL","Site URL:");
define("_FREFERENCE","De referentie naar onze site is verzonden naar");
define("_THANKSREC","Bedankt voor uw aanbeveling!");

?>
